from datetime import date, datetime
from django.utils.translation import gettext, gettext_lazy as _
from django.db import models


class ConfigType(models.TextChoices):
    TEXT = "T", _("Text")
    BOOL = "B", _("Boolean")
    INT = "I", _("Integer")
    FLOAT = "F", _("Float")
    DATE = "D", _("Date")
    DATETIME = "M", _("Datetime")
    ARRAY = "A", _("Array")


class Config(models.Model):
    key = models.SlugField(max_length=128, primary_key=True)
    value = models.TextField(null=True, blank=True)
    type = models.CharField(
        max_length=1, choices=ConfigType.choices, default=ConfigType.TEXT
    )

    def __str__(self):
        return f"{self.to_value()}"

    def to_value(self):
        if self.type == ConfigType.TEXT:
            return self.value
        if self.type == ConfigType.INT:
            return int(self.value)
        if self.type == ConfigType.BOOL:
            return self.value.lower() == "true"
        if self.type == ConfigType.FLOAT:
            return float(self.value)
        if self.type == ConfigType.DATE:
            return datetime.fromisoformat(self.value)
        if self.type == ConfigType.DATETIME:
            return datetime.fromisoformat(self.value)
        if self.type == ConfigType.ARRAY:
            return self.value.split(",")



# Generated by Django 5.0.3 on 2024-03-16 15:39

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Config",
            fields=[
                (
                    "key",
                    models.SlugField(max_length=128, primary_key=True, serialize=False),
                ),
                ("value", models.TextField(blank=True, null=True)),
                (
                    "type",
                    models.CharField(
                        choices=[
                            ("T", "Text"),
                            ("B", "Boolean"),
                            ("I", "Integer"),
                            ("F", "Float"),
                            ("D", "Date"),
                            ("M", "Datetime"),
                            ("A", "Array"),
                        ],
                        default="T",
                        max_length=1,
                    ),
                ),
            ],
        ),
    ]



from django.apps import AppConfig


class ConfigConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "tms_django_config"
    label = "Config"
    verbose_name = "Configurations"



from django.contrib import admin
from django.utils.translation import gettext, gettext_lazy as _
from tms_django_config import models


@admin.register(models.Config)
class ConfigAdmin(admin.ModelAdmin):
    list_display = ("key", "value", "type")
    search_fields = ["key", "value"]
    ordering = ["key"]



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="tms-django-config",
    version="1.0.0",
    url="https://github.com/tms-software/django-config",
    author="Franck COUTOULY",
    author_email="franck.coutouly@tms-software.ch",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    description="Simple config table with admin management",
    long_description=long_description,
    long_description_content_type="text/markdown",
    package_dir={"": "src"},
    packages=find_packages(where="src"),
    python_requires=">=3.6, <4",
    install_requires=["django", "django-admin"],
)
